##############################################
ttFont: Read/write OpenType and TrueType fonts
##############################################

.. autoclass:: fontTools.ttLib.ttFont.TTFont
   :inherited-members:
   :members:

.. autoclass:: fontTools.ttLib.ttFont.GlyphOrder
   :inherited-members:
   :members:
   :undoc-members:
   :private-members:

.. automodule:: fontTools.ttLib.ttFont
   :members: getTableModule, registerCustomTableClass, unregisterCustomTableClass, getCustomTableClass, getClassTag, newTable, tagToIdentifier, identifierToTag, tagToXML, xmlToTag, sortedTagList, reorderFontTables

